Simple CFDI
===========


Python library to manipulate CFDI (Comprobante Fiscal Digital por Internet) files.

This library is generated using [xsdata](https://github.com/tefra/xsdata) and the
XSD schema files from [SAT](https://www.sat.gob.mx/). See `utils/generate.sh` for
more details.

## Installation

```bash
pip install simple_cfdi

```

